@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 11:30:45
-@LastEditTime: 2022-04-27 10:11:41
+@LastEditTime: 2022-05-20 15:43:15
 @LastEditors: HuangJianYi
 @Description: 公共handler模块
 """
@@ -65,7 +65,7 @@ class FrameBaseHandler(BaseApiHandler):
             dict_param = self.get_http_log_extra_dict()
             self._build_http_log(dict_param)
             # 记录请求参数明文
-            if config.get_value("is_log_plain", True) == True and self.is_api_encrypt() == True:
+            if config.get_value("log_plain", True) == True and self.is_api_encrypt() == True:
                 self.logging_link_info(f"plain_request_params:{self.json_dumps(self.request_params)}")
 
 
@@ -620,7 +620,7 @@ class FrameBaseHandler(BaseApiHandler):
                 app_info_dict = app_base_model.get_app_info_dict(self.request_params.get("app_id",""))
                 if app_info_dict:
                     mp_base_model = MPBaseModel(context=self.context)
-                    result = mp_base_model.check_middle_power(app_info_dict["store_user_nick"], app_info_dict["project_code"], power_codes)
+                    result = mp_base_model.check_high_power(store_user_nick=app_info_dict["store_user_nick"], project_code=app_info_dict["project_code"], key_names=power_codes)
         return result
 
     def business_process_executing(self):
