@@ -26,7 +26,7 @@ class GoodsListHandler(ClientBaseHandler):
         :return: 列表
         :last_editors: HuangJianYi
         """
-        access_token = self.get_param("access_token")
+        access_token = self.get_access_token()
         goods_name = self.get_param("goods_name")
         order_tag = self.get_param("order_tag", "list_time")
         order_by = self.get_param("order_by", "desc")
@@ -55,7 +55,7 @@ class GoodsListByGoodsIDHandler(ClientBaseHandler):
         :return: list
         :last_editors: HuangJianYi
         """
-        access_token = self.get_param("access_token")
+        access_token = self.get_access_token()
         goods_ids = self.get_param("goods_ids")
         is_log = int(self.get_param("is_log", 0))
         is_log = True if is_log == 1 else False
@@ -80,7 +80,7 @@ class GoodsInfoHandler(ClientBaseHandler):
         :return: 商品信息
         :last_editors: HuangJianYi
         """
-        access_token = self.get_param("access_token")
+        access_token = self.get_access_token()
         goods_id = self.get_param("goods_id")
         is_log = int(self.get_param("is_log", 0))
         is_log = True if is_log == 1 else False
@@ -104,7 +104,7 @@ class BenefitDetailHandler(ClientBaseHandler):
         :return: dict
         :last_editors: HuangJianYi
         """
-        access_token = self.get_param("access_token")
+        access_token = self.get_access_token()
         right_ename = self.get_param("right_ename")
         is_log = int(self.get_param("is_log", 0))
         is_log = True if is_log == 1 else False
@@ -132,7 +132,7 @@ class InventoryGoodsListHandler(ClientBaseHandler):
         :return: 列表
         :last_editors: HuangJianYi
         """
-        access_token = self.get_param("access_token")
+        access_token = self.get_access_token()
         goods_name = self.get_param("goods_name")
         order_tag = self.get_param("order_tag", "list_time")
         order_by = self.get_param("order_by", "desc")
@@ -165,7 +165,7 @@ class SpecialGoodsListHandler(ClientBaseHandler):
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
         goods_name = self.get_param("goods_name")
-        access_token = self.get_param("access_token")
+        access_token = self.get_access_token()
         is_log = int(self.get_param("is_log", 0))
         is_log = True if is_log == 1 else False
 
@@ -191,7 +191,7 @@ class BindSpecialGoodsHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        access_token = self.get_param("access_token")
+        access_token = self.get_access_token()
         goods_id = self.get_param("goods_id")
         goods_name = self.get_param("goods_name")
         is_log = int(self.get_param("is_log", 0))
