@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-11-16 13:44:20
-@LastEditTime: 2022-01-10 16:15:19
+@LastEditTime: 2022-01-11 10:03:07
 @LastEditors: HuangJianYi
 :description: 报表模块
 """
@@ -38,7 +38,7 @@ class StatReportListHandler(ClientBaseHandler):
         if not invoke_result_data.data:
             invoke_result_data.data = {}
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index asc"
-        is_only_module = invoke_result_data.data["is_only_module"] if invoke_result_data.data.__contains__("is_only_module") else True
+        is_only_module = invoke_result_data.data["is_only_module"] if invoke_result_data.data.__contains__("is_only_module") else False
 
         stat_base_model = StatBaseModel(context=self)
         stat_report_list = stat_base_model.get_stat_report_list(app_id, act_id, module_id, start_date, end_date, order_by, is_only_module)
@@ -76,7 +76,7 @@ class TrendReportListHandler(ClientBaseHandler):
         if not invoke_result_data.data:
             invoke_result_data.data = {}
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index asc"
-        is_only_module = invoke_result_data.data["is_only_module"] if invoke_result_data.data.__contains__("is_only_module") else True
+        is_only_module = invoke_result_data.data["is_only_module"] if invoke_result_data.data.__contains__("is_only_module") else False
 
         stat_base_model = StatBaseModel(context=self)
         trend_report_list = stat_base_model.get_trend_report_list(app_id, act_id, module_id, start_date, end_date, order_by, is_only_module)
