@@ -289,7 +289,7 @@ class BatchUpdateUserAssetHandler(ClientBaseHandler):
         asset_object_json = SevenHelper.json_loads(asset_object_json)
         asset_object_ids = ""
         for asset_object in asset_object_json:
-            invoke_result_data = asset_base_model.update_user_asset(app_id, act_id, 0, user_id, user_info_dict["open_id"], user_info_dict["user_nick"], int(asset_object["asset_type"]), int(asset_object["asset_value"]), asset_object["asset_object_id"], 3, "", "手动配置", "手动配置")
+            invoke_result_data = asset_base_model.update_user_asset(app_id, act_id, 0, user_id, user_info_dict["open_id"], user_info_dict["user_nick"], int(asset_object["asset_type"]), int(asset_object["asset_value"]), asset_object["asset_object_id"], 3, "", "手动配置", "手动配置",handler_name = self.__class__.__name__,request_code = self.request_code)
             if invoke_result_data.success == False:
                 return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message, asset_object_ids)
             else:
