@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2022-04-29 16:11:57
+@LastEditTime: 2022-05-20 11:40:17
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -41,8 +41,8 @@ class StatConsoleModel():
                 j.start()
 
         clea_data_work = ClearDataWork()
-        clea_data_work.start_hours = 1
-        clea_data_work.end_hours = 1
+        clea_data_work.start_hours = 3
+        clea_data_work.end_hours = 4
         clea_data_work.sleep_time = 3600
         clea_data_work.start_work("清理统计流水数据作业")
 
@@ -125,16 +125,20 @@ class StatConsoleModel():
                                 stat_log_model.add_entity(stat_log)
                             stat_queue_model.del_entity("id=%s", params=[stat_queue.id])
                             del_stat_queue_model.add_entity(stat_queue)
-                            db_transaction.commit_transaction()
-
+                            result,message = db_transaction.commit_transaction(True)
+                            if result == False:
+                                raise Exception("执行事务失败", message)
                         except Exception as ex:
                             if db_transaction.is_transaction == True:
                                 db_transaction.rollback_transaction()
                             stat_queue.process_count += 1
-                            stat_queue.process_result = f"出现异常,json串:{SevenHelper.json_dumps(stat_queue)},ex:{traceback.format_exc()}"
-                            minute = 1 if stat_queue.process_count <= 5 else 5
-                            stat_queue.process_date = TimeHelper.add_minutes_by_format_time(minute=minute)
-                            stat_queue_model.update_entity(stat_queue, "process_count,process_result,process_date")
+                            if stat_queue.process_count <= 10:
+                                stat_queue.process_result = f"出现异常,json串:{SevenHelper.json_dumps(stat_queue)},ex:{traceback.format_exc()}"
+                                minute = 1 if stat_queue.process_count <= 5 else 5
+                                stat_queue.process_date = TimeHelper.add_minutes_by_format_time(minute=minute)
+                                stat_queue_model.update_entity(stat_queue, "process_count,process_result,process_date")
+                            else:
+                                logger_error.error(f"统计队列{mod_value}异常,json串:{SevenHelper.json_dumps(stat_queue)},ex:{traceback.format_exc()}")
                             continue
                 else:
                     time.sleep(1)
@@ -156,13 +160,15 @@ class StatConsoleModel():
                 time.sleep(0.1)
                 db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
                 stat_orm_model = StatOrmModel()
-                stat_queue_json = SevenHelper.redis_init().lpop(f"stat_queue_list:{mod_value}")
+                redis_init = SevenHelper.redis_init()
+                redis_stat_key = f"stat_queue_list:{mod_value}"
+                stat_queue_json = redis_init.lindex(redis_stat_key, index=0)
                 if not stat_queue_json:
                     time.sleep(1)
                     continue
                 try:
                     stat_queue_dict = SevenHelper.json_loads(stat_queue_json)
-                    frame_base_model = FrameBaseModel(context=self.context)
+                    frame_base_model = FrameBaseModel(context=None)
                     stat_log_model = StatLogModel(sub_table=frame_base_model.get_business_sub_table("stat_log_tb", {"act_id": stat_queue_dict["act_id"], "user_id": stat_queue_dict["user_id"]}), db_transaction=db_transaction)
                     stat_report_model = StatReportModel(sub_table=frame_base_model.get_business_sub_table("stat_report_tb", {"act_id": stat_queue_dict["act_id"], "user_id": 0}), db_transaction=db_transaction)
                     stat_orm = stat_orm_model.get_cache_entity("((act_id=%s and module_id=%s) or (act_id=0 and module_id=0)) and key_name=%s", params=[stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_queue_dict["key_name"]])
@@ -215,16 +221,16 @@ class StatConsoleModel():
                             key_value = stat_queue_dict["key_value"]
                             stat_report_model.update_table(f"key_value=key_value+{key_value}", stat_report_condition, params=stat_report_param)
                         stat_log_model.add_entity(stat_log)
-                        db_transaction.commit_transaction()
+                        result,message = db_transaction.commit_transaction(True)
+                        if result == False:
+                            raise Exception("执行事务失败", message)
+                        else:
+                            redis_init.lpop(redis_stat_key)
 
                 except Exception as ex:
                     if db_transaction.is_transaction == True:
                         db_transaction.rollback_transaction()
-                    stat_queue_dict["process_count"] += 1
-                    if stat_queue_dict["process_count"] <= 10:
-                        SevenHelper.redis_init().rpush(f"stat_queue_list:{mod_value}", SevenHelper.json_dumps(stat_queue_dict))
-                    else:
-                        logger_error.error(f"统计队列{mod_value}异常,json串:{SevenHelper.json_dumps(stat_queue_dict)},ex:{traceback.format_exc()}")
+                    logger_error.error(f"统计队列{mod_value}异常,json串:{SevenHelper.json_dumps(stat_queue_dict)},ex:{traceback.format_exc()}")
                     continue
 
             except Exception as ex:
@@ -239,12 +245,28 @@ class ClearDataWork(TimingWork):
     """
     def execute(self):
         invoke_result_data = InvokeResultData()
+        sub_table_config_list = config.get_value("sub_table_config_list",{})
+        sub_table_config = sub_table_config_list.get("stat_log_tb",{"sub_count":0,"sub_ways":0}) #sub_count分表数量，sub_ways分表方式（0-默认1-活动id取模2-用户id取模）
+        sub_count = sub_table_config.get("sub_count", 0)
+        if sub_count > 0:
+            self.process_sub_table(sub_count)
+        else:
+            self.process_only_table()
+
+        return invoke_result_data
+
+    def process_only_table(self):
+        """
+        :description: 处理单表
+        :return: 
+        :last_editors: HuangJianYi
+        """
         stat_log_model = StatLogModel()
         stat_orm_model = StatOrmModel()
         page_index = 0
         while True:
-            stat_orm_dict_list,total =  stat_orm_model.get_dict_page_list(field="id,repeat_type",page_index=page_index,page_size=50,order_by="id asc")
-            if len(stat_orm_dict_list) <=0:
+            stat_orm_dict_list, total = stat_orm_model.get_dict_page_list(field="id,repeat_type", page_index=page_index, page_size=50, order_by="id asc")
+            if len(stat_orm_dict_list) <= 0:
                 break
             for stat_orm_dict in stat_orm_dict_list:
                 if stat_orm_dict["repeat_type"] != 2:
@@ -253,4 +275,26 @@ class ClearDataWork(TimingWork):
                         if is_del == False:
                             break
             page_index += 1
-        return invoke_result_data
+
+    def process_sub_table(self, sub_count):
+        """
+        :description: 处理分表
+        :param sub_count: 分表数量
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        stat_orm_model = StatOrmModel()
+        page_index = 0
+        while True:
+            stat_orm_dict_list, total = stat_orm_model.get_dict_page_list(field="id,repeat_type", page_index=page_index, page_size=50, order_by="id asc")
+            if len(stat_orm_dict_list) <= 0:
+                break
+            for stat_orm_dict in stat_orm_dict_list:
+                if stat_orm_dict["repeat_type"] != 2:
+                    for i in range(sub_count):
+                        stat_log_model = StatLogModel(sub_table=str(i))
+                        while True:
+                            is_del = stat_log_model.del_entity("orm_id=%s and create_day<%s", params=[stat_orm_dict["id"], SevenHelper.get_now_day_int(-24 * 15)], limit="1000")
+                            if is_del == False:
+                                break
+            page_index += 1
