@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:55:09
-@LastEditTime: 2021-09-09 11:31:15
+@LastEditTime: 2021-11-29 14:10:17
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -33,7 +33,7 @@ class PrizeRoster:
         self.open_id = ""  # open_id
         self.user_nick = ""  # 用户昵称
         self.order_no = ""  # 订单号
-        self.source_type = 0  # 来源类型（1-购买2-任务3-兑换）
+        self.source_type = 0  # 来源类型（0-活动奖品1-任务奖品2-兑换奖品）业务自定义从101开始
         self.source_object_id = ""  # 来源对象标识
         self.module_id = 0  # 活动模块标识
         self.module_name = ""  # 活动模块名称
