@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-11 09:10:33
-@LastEditTime: 2022-04-27 16:12:17
+@LastEditTime: 2022-05-24 21:03:05
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -17,8 +17,16 @@ class FrameBaseModel():
     """
     :description: 框架业务模型 用于被其他业务模型继承，调用模型之间通用的方法
     """
-    def __init__(self, context):
+    def __init__(self, context=None):
         self.context = context
+        self.acquire_lock_name = ""
+        self.identifier = ""
+        self.request_queue_name = ""
+        self.handler_name = ""
+        self.act_id = 0
+        self.module_id = 0
+        self.user_id = 0
+        self.source_object_id = ""
 
     def score_algorithm_to_score(self, weight):
         """
@@ -203,16 +211,6 @@ class FrameBaseModel():
                 invoke_result_data.error_code = "error"
                 invoke_result_data.error_message = f"对不起,请{continue_request_expire}秒后再试"
                 return invoke_result_data
-        request_queue_name = ""
-        if request_limit_num > 0  and request_limit_time > 0:
-            request_queue_name = f"request_queue:{handler_name}_{act_id}_{module_id}"
-            if SevenHelper.redis_check_llen(request_queue_name,request_limit_num) == True:
-                invoke_result_data.success = False
-                invoke_result_data.error_code = "concurrent"
-                invoke_result_data.error_message = "当前人数过多,请稍后再试"
-                return invoke_result_data
-            SevenHelper.redis_lpush(request_queue_name,user_id,request_limit_time)
-
         act_info_model = ActInfoModel(context=self.context)
         act_info_dict = act_info_model.get_cache_dict_by_id(act_id,dependency_key=f"act_info:actid_{act_id}")
         if not act_info_dict or act_info_dict["is_release"] == 0 or act_info_dict["is_del"] == 1:
@@ -300,8 +298,17 @@ class FrameBaseModel():
             if acquire_lock_status == False:
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "acquire_lock"
-                invoke_result_data.error_message = "系统繁忙,请稍后再试"
+                invoke_result_data.error_message = "当前人气火爆,请稍后再试"
                 return invoke_result_data
+        request_queue_name = ""
+        if request_limit_num > 0  and request_limit_time > 0:
+            request_queue_name = f"request_queue:{handler_name}_{act_id}_{module_id}"
+            if SevenHelper.redis_check_llen(request_queue_name,request_limit_num) == True:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "concurrent"
+                invoke_result_data.error_message = "当前人气火爆,请稍后再试"
+                return invoke_result_data
+            SevenHelper.redis_lpush(request_queue_name,user_id,request_limit_time)
 
         invoke_result_data.data = {}
         invoke_result_data.data["act_info_dict"] = act_info_dict
@@ -309,11 +316,21 @@ class FrameBaseModel():
         invoke_result_data.data["user_info_dict"] = user_info_dict
         invoke_result_data.data["identifier"] = identifier
         invoke_result_data.data["request_queue_name"] = request_queue_name
+        
+        self.acquire_lock_name = acquire_lock_name
+        self.identifier = identifier
+        self.request_queue_name = request_queue_name
+        self.handler_name = handler_name
+        self.act_id = act_id
+        self.module_id = module_id
+        self.user_id = user_id
+        self.source_object_id = source_object_id
+        
         return invoke_result_data
 
-    def business_process_executed(self,act_id,module_id,user_id,handler_name,acquire_lock_name="",identifier="",request_queue_name="",source_object_id=""):
+    def business_process_executed(self,act_id=0,module_id=0,user_id=0,handler_name="",acquire_lock_name="",identifier="",request_queue_name="",source_object_id=""):
         """
-        :description: 业务执行后事件，调用了业务执行前事件需要调用当前方法
+        :description: 业务执行后事件，调用了业务执行前事件需要调用当前方法,参数可以不传，默认用business_process_executing方法传递的参数
         :param act_id:活动标识
         :param module_id:活动模块标识
         :param user_id:用户标识
@@ -325,6 +342,23 @@ class FrameBaseModel():
         :return:
         :last_editors: HuangJianYi
         """
+        if not acquire_lock_name:
+            acquire_lock_name = self.acquire_lock_name
+        if not identifier:
+            identifier = self.identifier
+        if not request_queue_name:
+            request_queue_name = self.request_queue_name
+        if not source_object_id:
+            source_object_id = self.source_object_id
+        if not handler_name:
+            handler_name = self.handler_name
+        if not act_id:
+            act_id = self.act_id
+        if not module_id:
+            module_id = self.module_id
+        if not user_id:
+            user_id = self.user_id
+             
         continue_request_key = f"request_business_executing:{handler_name}_{act_id}_{module_id}_{user_id}"
         if source_object_id:
             continue_request_key += f"_{source_object_id}"
