@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 09:44:36
-@LastEditTime: 2022-02-25 14:11:04
+@LastEditTime: 2022-04-28 16:23:36
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -21,7 +21,7 @@ class IpBaseModel():
         self.logging_link_error = logging_error
         self.logging_link_info = logging_info
 
-    def _delete_ip_info_dependency_key(self, act_id, delay_delete_time=0.1):
+    def _delete_ip_info_dependency_key(self, act_id, delay_delete_time=0.01):
         """
         :description: 删除ip信息依赖建
         :param act_id: 活动标识
@@ -127,11 +127,12 @@ class IpBaseModel():
             page_list, total = IpInfoModel(context=self.context).get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list)
         return page_list, total
 
-    def delete_ip_info(self,app_id,ip_id):
+    def update_ip_info_status(self,app_id,ip_id,is_del):
         """
         :description: 删除ip
         :param app_id：应用标识
         :param ip_id：ip标识
+        :param is_del：0-还原，1-删除
         :return: 
         :last_editors: HuangJianYi
         """
@@ -143,8 +144,9 @@ class IpBaseModel():
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "ip信息不存在"
             return invoke_result_data
-
-        invoke_result_data.success = ip_info_model.update_table("is_del=%s", "id=%s", [1, ip_id])
+        is_release = 0 if is_del == 1 else 1
+        modify_date = SevenHelper.get_now_datetime()
+        invoke_result_data.success = ip_info_model.update_table("is_del=%s,is_release=%s,modify_date=%s", "id=%s", [is_del, is_release, modify_date, ip_id])
         self._delete_ip_info_dependency_key(ip_info_dict["act_id"])
         return invoke_result_data
 
