@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2022-04-29 15:13:24
+@LastEditTime: 2022-05-31 15:13:50
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -211,7 +211,7 @@ class UserBaseModel(FrameBaseModel):
         user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
         now_datetime = SevenHelper.get_now_datetime()
         try:
-            user_account = user_account_model.get_entity("open_id=%s", params=[open_id])
+            user_account = user_account_model.get_cache_entity("open_id=%s", params=[open_id], dependency_key=f"user_account:openid_{open_id}")
             if not user_account:
                 user_account = UserAccount()
                 user_account.union_id = union_id
@@ -230,7 +230,7 @@ class UserBaseModel(FrameBaseModel):
                 user_account.avatar = avatar if avatar and user_account.avatar != avatar else user_account.avatar
                 user_account_model.update_entity(user_account, "user_nick,user_nick_encrypt,avatar")
 
-            user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
+            user_info = user_info_model.get_cache_entity("act_id=%s and open_id=%s", params=[act_id, open_id], dependency_key=self.get_user_info_dependency_key(act_id,"",open_id))
             if not user_info:
                 user_info = UserInfo()
                 user_info.id_md5 = self._get_user_info_id_md5(act_id, user_account.id)
@@ -265,7 +265,7 @@ class UserBaseModel(FrameBaseModel):
                 user_info.login_token = SevenHelper.get_random(16)
                 user_info_model.update_entity(user_info, "modify_date,login_token,is_new,user_nick,user_nick_encrypt,avatar,is_auth")
 
-                self._delete_user_info_cache(user_info.act_id, user_info.id_md5)
+                user_info_model.delete_dependency_key([f"user_account:openid_{open_id}",self.get_user_info_dependency_key(act_id, user_info.id_md5), self.get_user_info_dependency_key(act_id, "", user_info.open_id)])
 
         except Exception as ex:
             if self.context:
@@ -402,7 +402,7 @@ class UserBaseModel(FrameBaseModel):
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
+        db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"),context=self.context)
         user_info_model = UserInfoModel(db_transaction=db_transaction,sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0}), context=self.context)
         user_black_model = UserBlackModel(db_transaction=db_transaction, context=self.context)
 
@@ -449,12 +449,9 @@ class UserBaseModel(FrameBaseModel):
                 user_black.reason = reason
                 user_black.create_date = SevenHelper.get_now_datetime()
                 user_black_model.update_entity(user_black)
-            result = db_transaction.commit_transaction()
+            result,mesage = db_transaction.commit_transaction(True)
             if not result:
-                invoke_result_data.success = False
-                invoke_result_data.error_code = "fail"
-                invoke_result_data.error_message = "系统繁忙,请稍后再试"
-                return invoke_result_data
+                raise Exception("执行事务失败",mesage)
             invoke_result_data.data = {"user_info": user_info_dict}
             self._delete_user_info_cache(user_info_dict["act_id"], user_info_dict["id_md5"])
             self._delete_user_black_cache(act_id, user_id)
